# FINAM-NetCDF

FINAM components for reading and writing spatial and temporal data from and to [NetCDF](https://www.unidata.ucar.edu/software/netcdf/) files.

<a href="https://finam.pages.ufz.de/finam-netcdf" title="FINAM NetCDF homepage" target="_blank">
  <img width="300" src="https://git.ufz.de/FINAM/finam-netcdf/-/raw/main/docs/source/_static/logo_large.svg" />
</a>

See the FINAM-NetCDF [documentation](https://finam.pages.ufz.de/finam-netcdf).

## License

LGPLv3, Copyright © 2021-2025, the FINAM developers from Helmholtz-Zentrum für Umweltforschung GmbH - UFZ. All rights reserved.
